.. nodoctest

Percolation in lattices
=======================

.. This file has been autogenerated.

.. automodule:: slabbe.bond_percolation
   :members:
   :undoc-members:
   :show-inheritance:
   

